==> catjs-0.4.56.tgz: package/test/cat-poc/app/cat-project/target/test/cat/lib/cat/cat.src.js <==
_cat.core.define("test.app.scrap_9b32f031-7618-28db-6ac2-5a772c0aa709$$cat", function(thi$) {

  var pkgName = "test.app.scrap_9b32f031-7618-28db-6ac2-5a772c0aa709$$cat",
    _argsrefs = arguments,
    _argsnames = "thi$",
    _args = {},
    _ipkg = _cat.core.getVar(pkgName),
    context,
    _counter = 0;

  if (_args) {
    _argsnames = _argsnames.split(",");
    _argsnames.forEach(function(arg) {
      _args[arg] = _argsrefs[_counter];
      _counter++;
    });
  }

  context = {
    scrap: _ipkg.scrap,
    args: _args
  };


  /* test content in here */

});
_cat.core.define("test.app.testButtonClick$$cat", function(thi$, testButton) {

  var pkgName = "test.app.testButtonClick$$cat",
    _argsrefs = arguments,
    _argsnames = "thi$,testButton",
    _args = {},
    _ipkg = _cat.core.getVar(pkgName),
    context,
    _counter = 0;

  if (_args) {
    _argsnames = _argsnames.split(",");
    _argsnames.forEach(function(arg) {
      _args[arg] = _argsrefs[_counter];
      _counter++;
    });
  }

  context = {
    scrap: _ipkg.scrap,
    args: _args
  };


  /* test content in here */
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        _cat.utils.chai.assert(context);
      }
    ],
    context: {
      'code': ["assert", "ok(testButton[0],\"No valid test element button\")\n"].join("."),
      'fail': true,
      scrapName: 'assert',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 0
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        testButton.click();
      }
    ],
    context: {
      scrapName: 'code',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 0
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        /*  Generated log statement according to the scrap comment (see @@code) */
        console.log("test 1");
      }
    ],
    context: {
      scrapName: 'log',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 0
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        /*  Generated log statement according to the scrap comment (see @@code) */
        console.log("test 1.1");
      }
    ],
    context: {
      scrapName: 'log',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 1
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        testButton.click();
      }
    ],
    context: {
      scrapName: 'code',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 1
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        /*  Generated log statement according to the scrap comment (see @@code) */
        console.log("test 2");
      }
    ],
    context: {
      scrapName: 'log',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 2
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        testButton.click();
      }
    ],
    context: {
      scrapName: 'code',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 2
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        /*  Generated log statement according to the scrap comment (see @@code) */
        console.log("test 3");
      }
    ],
    context: {
      scrapName: 'log',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 3
    }
  });
});
_cat.core.define("test.app.testButtonListener$$cat", function(thi$, counter, description) {

  var pkgName = "test.app.testButtonListener$$cat",
    _argsrefs = arguments,
    _argsnames = "thi$,counter,description",
    _args = {},
    _ipkg = _cat.core.getVar(pkgName),
    context,
    _counter = 0;

  if (_args) {
    _argsnames = _argsnames.split(",");
    _argsnames.forEach(function(arg) {
      _args[arg] = _argsrefs[_counter];
      _counter++;
    });
  }

  context = {
    scrap: _ipkg.scrap,
    args: _args
  };


  /* test content in here */
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, counter, description) {
        /*  Generated log statement according to the scrap comment (see @@code) */
        console.log("Description: ", description.text().trim());
      }
    ],
    context: {
      scrapName: 'log',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 0
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, counter, description) {
        _cat.utils.chai.assert(context);
      }
    ],
    context: {
      'code': ["assert", "ok(counter<3,\"More then 2 clicks is too much...\")\n"].join("."),
      'fail': true,
      scrapName: 'assert',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 0
    }
  });
});
_cat.core.declare('test.app.scrap_9b32f031-7618-28db-6ac2-5a772c0aa709$$cat', {
  scrap: {
    "stack": [{
      "key": "describe",
      "cell": 0
    }, {
      "key": "it",
      "cell": 0
    }, {
      "key": "describe",
      "cell": 1
    }, {
      "key": "it",
      "cell": 1
    }, {
      "key": "it",
      "cell": 2
    }],
    "describe": ["\"MainTest\"   ", "\"The first describe\""],
    "it": ["\"first it\"", "\"is going to help me with test annotations\"", "\"and validate the solution\"   "],
    "file": "/home/arik/dev/projects/lastboy/catjs/test/cat-poc/app/cat-project/target/test/app.js",
    "scrapinfo": {
      "start": {
        "line": 6,
        "col": 3
      },
      "end": {
        "line": 12,
        "col": 5
      }
    },
    "commentinfo": {
      "start": {
        "line": 3,
        "col": 0
      },
      "end": {
        "line": 14,
        "col": 3
      }
    },
    "name": "scrap_9b32f031-7618-28db-6ac2-5a772c0aa709",
    "single": {
      "stack": true,
      "describe": false,
      "it": false,
      "file": true,
      "scrapinfo": true,
      "commentinfo": true,
      "name": true,
      "single": true,
      "singleton": true,
      "arguments": true,
      "context": false,
      "auto": true,
      "injectcode": true,
      "$standalone": true,
      "id": true,
      "$type": true
    },
    "singleton": {
      "stack": -1,
      "describe": -1,
      "it": -1,
      "file": -1,
      "scrapinfo": -1,
      "commentinfo": -1,
      "name": -1,
      "single": -1,
      "singleton": -1,
      "arguments": -1,
      "context": 2,
      "auto": -1,
      "injectcode": -1,
      "$standalone": -1,
      "id": -1,
      "$type": -1
    },
    "arguments": ["thi$"],
    "context": ["thi$"],
    "auto": false,
    "injectcode": false,
    "$standalone": false,
    "id": "scrap_9b32f031-7618-28db-6ac2-5a772c0aa709",
    "$type": "js",
    "pkgName": "test.app.scrap_9b32f031-7618-28db-6ac2-5a772c0aa709"
  }
}, 'scrap');
_cat.core.declare('test.app.testButtonClick$$cat', {
  scrap: {
    "stack": [{
      "key": "name",
      "cell": 0
    }, {
      "key": "context",
      "cell": 0
    }, {
      "key": "assert",
      "cell": 0
    }, {
      "key": "code",
      "cell": 0
    }, {
      "key": "log",
      "cell": 0
    }, {
      "key": "log",
      "cell": 1
    }, {
      "key": "code",
      "cell": 1
    }, {
      "key": "log",
      "cell": 2
    }, {
      "key": "code",
      "cell": 2
    }, {
      "key": "log",
      "cell": 3
    }],
    "name": ["testButtonClick"],
    "context": ["thi$", "testButton"],
    "assert": ["ok(testButton[0], \"No valid test element button\");"],
    "code": ["testButton.click();", "testButton.click();", "testButton.click();"],
    "log": ["\"test 1\"", "\"test 1.1\"", "\"test 2\"", "\"test 3\""],
    "file": "/home/arik/dev/projects/lastboy/catjs/test/cat-poc/app/cat-project/target/test/app.js",
    "scrapinfo": {
      "start": {
        "line": 23,
        "col": 5
      },
      "end": {
        "line": 34,
        "col": 7
      }
    },
    "commentinfo": {
      "start": {
        "line": 20,
        "col": 4
      },
      "end": {
        "line": 35,
        "col": 7
      }
    },
    "single": {
      "stack": true,
      "name": true,
      "context": false,
      "assert": false,
      "code": false,
      "log": false,
      "file": true,
      "scrapinfo": true,
      "commentinfo": true,
      "single": true,
      "singleton": true,
      "arguments": true,
      "auto": true,
      "injectcode": true,
      "$standalone": true,
      "id": true,
      "$type": true
    },
    "singleton": {
      "stack": -1,
      "name": -1,
      "context": 2,
      "assert": -1,
      "code": 2,
      "log": 2,
      "file": -1,
      "scrapinfo": -1,
      "commentinfo": -1,
      "single": -1,
      "singleton": -1,
      "arguments": -1,
      "auto": -1,
      "injectcode": -1,
      "$standalone": -1,
      "id": -1,
      "$type": -1
    },
    "arguments": ["thi$", "testButton"],
    "auto": true,
    "injectcode": false,
    "$standalone": false,
    "id": "scrap_c6ef8961-f9c6-becd-0456-9019c24e625d",
    "$type": "js",
    "pkgName": "test.app.testButtonClick"
  }
}, 'scrap');
_cat.core.declare('test.app.testButtonListener$$cat', {
  scrap: {
    "stack": [{
      "key": "name",
      "cell": 0
    }, {
      "key": "standalone",
      "cell": 0
    }, {
      "key": "context",
      "cell": 1
    }, {
      "key": "log",
      "cell": 0
    }, {
      "key": "assert",
      "cell": 0
    }],
    "name": ["testButtonListener"],
    "standalone": ["true"],
    "context": ["thi$", "counter", "description"],
    "log": ["\"Description: \", description.text().trim()"],
    "assert": ["ok((counter < 3), \"More then 2 clicks is too much...\");"],
    "file": "/home/arik/dev/projects/lastboy/catjs/test/cat-poc/app/cat-project/target/test/app.js",
    "scrapinfo": {
      "start": {
        "line": 48,
        "col": 13
      },
      "end": {
        "line": 57,
        "col": 15
      }
    },
    "commentinfo": {
      "start": {
        "line": 45,
        "col": 12
      },
      "end": {
        "line": 58,
        "col": 15
      }
    },
    "single": {
      "stack": true,
      "name": true,
      "standalone": true,
      "context": false,
      "log": false,
      "assert": false,
      "file": true,
      "scrapinfo": true,
      "commentinfo": true,
      "single": true,
      "singleton": true,
      "arguments": true,
      "auto": true,
      "injectcode": true,
      "$standalone": true,
      "id": true,
      "$type": true
    },
    "singleton": {
      "stack": -1,
      "name": -1,
      "standalone": -1,
      "context": 2,
      "log": 2,
      "assert": -1,
      "file": -1,
      "scrapinfo": -1,
      "commentinfo": -1,
      "single": -1,
      "singleton": -1,
      "arguments": -1,
      "auto": -1,
      "injectcode": -1,
      "$standalone": -1,
      "id": -1,
      "$type": -1
    },
    "arguments": ["thi$", "counter", "description"],
    "auto": true,
    "injectcode": false,
    "$standalone": true,
    "id": "scrap_0c9a8c1c-f310-f650-ea91-4365229df6ff",
    "$type": "js",
    "pkgName": "test.app.testButtonListener"
  }
}, 'scrap');

==> catjs-0.5.0.tgz: package/test/cat-poc/app/cat-project/target/test/cat/lib/cat/cat.src.js <==
_cat.core.define("test.app.scrap_965eb7eb-f838-0eae-4103-533fc426339c$$cat", function(thi$) {

  var pkgName = "test.app.scrap_965eb7eb-f838-0eae-4103-533fc426339c$$cat",
    _argsrefs = arguments,
    _argsnames = "thi$",
    _args = {},
    _ipkg = _cat.core.getVar(pkgName),
    context,
    _counter = 0;

  if (_args) {
    _argsnames = _argsnames.split(",");
    _argsnames.forEach(function(arg) {
      _args[arg] = _argsrefs[_counter];
      _counter++;
    });
  }

  context = {
    scrap: _ipkg.scrap,
    args: _args
  };


  /* test content in here */

});
_cat.core.define("test.app.testButtonClick$$cat", function(thi$, testButton) {

  var pkgName = "test.app.testButtonClick$$cat",
    _argsrefs = arguments,
    _argsnames = "thi$,testButton",
    _args = {},
    _ipkg = _cat.core.getVar(pkgName),
    context,
    _counter = 0;

  if (_args) {
    _argsnames = _argsnames.split(",");
    _argsnames.forEach(function(arg) {
      _args[arg] = _argsrefs[_counter];
      _counter++;
    });
  }

  context = {
    scrap: _ipkg.scrap,
    args: _args
  };


  /* test content in here */
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        _cat.utils.chai.assert(context);
      }
    ],
    context: {
      'code': ["assert", "ok(testButton[0],\"No valid test element button\")\n"].join("."),
      'fail': true,
      scrapName: 'assert',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 0
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        testButton.click();
      }
    ],
    context: {
      scrapName: 'code',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 0
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        /*  Generated log statement according to the scrap comment (see @@code) */
        console.log("test 1");
      }
    ],
    context: {
      scrapName: 'log',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 0
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        /*  Generated log statement according to the scrap comment (see @@code) */
        console.log("test 1.1");
      }
    ],
    context: {
      scrapName: 'log',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 1
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        testButton.click();
      }
    ],
    context: {
      scrapName: 'code',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 1
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        /*  Generated log statement according to the scrap comment (see @@code) */
        console.log("test 2");
      }
    ],
    context: {
      scrapName: 'log',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 2
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        testButton.click();
      }
    ],
    context: {
      scrapName: 'code',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 2
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, testButton) {
        /*  Generated log statement according to the scrap comment (see @@code) */
        console.log("test 3");
      }
    ],
    context: {
      scrapName: 'log',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 3
    }
  });
});
_cat.core.define("test.app.testButtonListener$$cat", function(thi$, counter, description) {

  var pkgName = "test.app.testButtonListener$$cat",
    _argsrefs = arguments,
    _argsnames = "thi$,counter,description",
    _args = {},
    _ipkg = _cat.core.getVar(pkgName),
    context,
    _counter = 0;

  if (_args) {
    _argsnames = _argsnames.split(",");
    _argsnames.forEach(function(arg) {
      _args[arg] = _argsrefs[_counter];
      _counter++;
    });
  }

  context = {
    scrap: _ipkg.scrap,
    args: _args
  };


  /* test content in here */
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, counter, description) {
        /*  Generated log statement according to the scrap comment (see @@code) */
        console.log("Description: ", description.text().trim());
      }
    ],
    context: {
      scrapName: 'log',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 0
    }
  });
  _cat.core.clientmanager.delayManager({
    commands: [
      function(context, thi$, counter, description) {
        _cat.utils.chai.assert(context);
      }
    ],
    context: {
      'code': ["assert", "ok(counter<3,\"More then 2 clicks is too much...\")\n"].join("."),
      'fail': true,
      scrapName: 'assert',
      scrap: _ipkg.scrap,
      args: _args,
      scrapRowIdx: 0
    }
  });
});
_cat.core.declare('test.app.scrap_965eb7eb-f838-0eae-4103-533fc426339c$$cat', {
  scrap: {
    "stack": [{
      "key": "describe",
      "cell": 0
    }, {
      "key": "it",
      "cell": 0
    }, {
      "key": "describe",
      "cell": 1
    }, {
      "key": "it",
      "cell": 1
    }, {
      "key": "it",
      "cell": 2
    }],
    "describe": ["\"MainTest\"   ", "\"The first describe\""],
    "it": ["\"first it\"", "\"is going to help me with test annotations\"", "\"and validate the solution\"   "],
    "file": "/home/arik/dev/projects/lastboy/catjs/test/cat-poc/app/cat-project/target/test/app.js",
    "scrapinfo": {
      "start": {
        "line": 6,
        "col": 3
      },
      "end": {
        "line": 12,
        "col": 5
      }
    },
    "commentinfo": {
      "start": {
        "line": 3,
        "col": 0
      },
      "end": {
        "line": 14,
        "col": 3
      }
    },
    "name": "scrap_965eb7eb-f838-0eae-4103-533fc426339c",
    "single": {
      "stack": true,
      "describe": false,
      "it": false,
      "file": true,
      "scrapinfo": true,
      "commentinfo": true,
      "name": true,
      "single": true,
      "singleton": true,
      "arguments": true,
      "context": false,
      "auto": true,
      "injectcode": true,
      "$standalone": true,
      "id": true,
      "$type": true
    },
    "singleton": {
      "stack": -1,
      "describe": -1,
      "it": -1,
      "file": -1,
      "scrapinfo": -1,
      "commentinfo": -1,
      "name": -1,
      "single": -1,
      "singleton": -1,
      "arguments": -1,
      "context": 2,
      "auto": -1,
      "injectcode": -1,
      "$standalone": -1,
      "id": -1,
      "$type": -1
    },
    "arguments": ["thi$"],
    "context": ["thi$"],
    "auto": false,
    "injectcode": false,
    "$standalone": false,
    "id": "scrap_965eb7eb-f838-0eae-4103-533fc426339c",
    "$type": "js",
    "pkgName": "test.app.scrap_965eb7eb-f838-0eae-4103-533fc426339c"
  }
}, 'scrap');
_cat.core.declare('test.app.testButtonClick$$cat', {
  scrap: {
    "stack": [{
      "key": "name",
      "cell": 0
    }, {
      "key": "context",
      "cell": 0
    }, {
      "key": "assert",
      "cell": 0
    }, {
      "key": "code",
      "cell": 0
    }, {
      "key": "log",
      "cell": 0
    }, {
      "key": "log",
      "cell": 1
    }, {
      "key": "code",
      "cell": 1
    }, {
      "key": "log",
      "cell": 2
    }, {
      "key": "code",
      "cell": 2
    }, {
      "key": "log",
      "cell": 3
    }],
    "name": ["testButtonClick"],
    "context": ["thi$", "testButton"],
    "assert": ["ok(testButton[0], \"No valid test element button\");"],
    "code": ["testButton.click();", "testButton.click();", "testButton.click();"],
    "log": ["\"test 1\"", "\"test 1.1\"", "\"test 2\"", "\"test 3\""],
    "file": "/home/arik/dev/projects/lastboy/catjs/test/cat-poc/app/cat-project/target/test/app.js",
    "scrapinfo": {
      "start": {
        "line": 23,
        "col": 5
      },
      "end": {
        "line": 34,
        "col": 7
      }
    },
    "commentinfo": {
      "start": {
        "line": 20,
        "col": 4
      },
      "end": {
        "line": 35,
        "col": 7
      }
    },
    "single": {
      "stack": true,
      "name": true,
      "context": false,
      "assert": false,
      "code": false,
      "log": false,
      "file": true,
      "scrapinfo": true,
      "commentinfo": true,
      "single": true,
      "singleton": true,
      "arguments": true,
      "auto": true,
      "injectcode": true,
      "$standalone": true,
      "id": true,
      "$type": true
    },
    "singleton": {
      "stack": -1,
      "name": -1,
      "context": 2,
      "assert": -1,
      "code": 2,
      "log": 2,
      "file": -1,
      "scrapinfo": -1,
      "commentinfo": -1,
      "single": -1,
      "singleton": -1,
      "arguments": -1,
      "auto": -1,
      "injectcode": -1,
      "$standalone": -1,
      "id": -1,
      "$type": -1
    },
    "arguments": ["thi$", "testButton"],
    "auto": true,
    "injectcode": false,
    "$standalone": false,
    "id": "scrap_d3473729-f1b0-59d8-9d03-8120d84c7ea8",
    "$type": "js",
    "pkgName": "test.app.testButtonClick"
  }
}, 'scrap');
_cat.core.declare('test.app.testButtonListener$$cat', {
  scrap: {
    "stack": [{
      "key": "name",
      "cell": 0
    }, {
      "key": "standalone",
      "cell": 0
    }, {
      "key": "context",
      "cell": 1
    }, {
      "key": "log",
      "cell": 0
    }, {
      "key": "assert",
      "cell": 0
    }],
    "name": ["testButtonListener"],
    "standalone": ["true"],
    "context": ["thi$", "counter", "description"],
    "log": ["\"Description: \", description.text().trim()"],
    "assert": ["ok((counter < 3), \"More then 2 clicks is too much...\");"],
    "file": "/home/arik/dev/projects/lastboy/catjs/test/cat-poc/app/cat-project/target/test/app.js",
    "scrapinfo": {
      "start": {
        "line": 48,
        "col": 13
      },
      "end": {
        "line": 57,
        "col": 15
      }
    },
    "commentinfo": {
      "start": {
        "line": 45,
        "col": 12
      },
      "end": {
        "line": 58,
        "col": 15
      }
    },
    "single": {
      "stack": true,
      "name": true,
      "standalone": true,
      "context": false,
      "log": false,
      "assert": false,
      "file": true,
      "scrapinfo": true,
      "commentinfo": true,
      "single": true,
      "singleton": true,
      "arguments": true,
      "auto": true,
      "injectcode": true,
      "$standalone": true,
      "id": true,
      "$type": true
    },
    "singleton": {
      "stack": -1,
      "name": -1,
      "standalone": -1,
      "context": 2,
      "log": 2,
      "assert": -1,
      "file": -1,
      "scrapinfo": -1,
      "commentinfo": -1,
      "single": -1,
      "singleton": -1,
      "arguments": -1,
      "auto": -1,
      "injectcode": -1,
      "$standalone": -1,
      "id": -1,
      "$type": -1
    },
    "arguments": ["thi$", "counter", "description"],
    "auto": true,
    "injectcode": false,
    "$standalone": true,
    "id": "scrap_629d195c-9ac3-69d1-fa58-35c9c55d772b",
    "$type": "js",
    "pkgName": "test.app.testButtonListener"
  }
}, 'scrap');
